pub struct BaseTester { /* private fields */ }Expand description
Helper to facilitate easier writing of tests using RangeChip and RangeCircuitBuilder.
By default, the MockProver is used.
Currently this tester uses all private inputs.
Implementations
Sourceimpl BaseTester
impl BaseTester
Sourcepub fn k(self, k: u32) -> Self
pub fn k(self, k: u32) -> Self
Changes the number of rows in the circuit to 2k.
By default it will also set lookup bits as large as possible, to k - 1.
Sourcepub fn lookup_bits(self, lookup_bits: usize) -> Self
pub fn lookup_bits(self, lookup_bits: usize) -> Self
Sets the size of the lookup table used for range checks to [0, 2lookup_bits)
Sourcepub fn expect_satisfied(self, expect_satisfied: bool) -> Self
pub fn expect_satisfied(self, expect_satisfied: bool) -> Self
Specify whether you expect this test to pass or fail. Default: pass
Sourcepub fn unusable_rows(self, unusable_rows: usize) -> Self
pub fn unusable_rows(self, unusable_rows: usize) -> Self
Set the number of blinding (poisoned) rows
Sourcepub fn run<R>(&self, f: impl FnOnce(&mut Context<Fr>, &RangeChip<Fr>) -> R) -> R
pub fn run<R>(&self, f: impl FnOnce(&mut Context<Fr>, &RangeChip<Fr>) -> R) -> R
Run a mock test by providing a closure that uses a ctx and RangeChip.
expect_satisfied: flag for whether you expect the test to pass or fail. Failure means a constraint system failure – the tester does not catch system panics.
Sourcepub fn run_gate<R>(
&self,
f: impl FnOnce(&mut Context<Fr>, &GateChip<Fr>) -> R,
) -> R
pub fn run_gate<R>( &self, f: impl FnOnce(&mut Context<Fr>, &GateChip<Fr>) -> R, ) -> R
Run a mock test by providing a closure that uses a ctx and GateChip.
expect_satisfied: flag for whether you expect the test to pass or fail. Failure means a constraint system failure – the tester does not catch system panics.
Sourcepub fn run_builder<R>(
&self,
f: impl FnOnce(&mut SinglePhaseCoreManager<Fr>, &RangeChip<Fr>) -> R,
) -> R
pub fn run_builder<R>( &self, f: impl FnOnce(&mut SinglePhaseCoreManager<Fr>, &RangeChip<Fr>) -> R, ) -> R
Run a mock test by providing a closure that uses a builder and RangeChip.
Sourcepub fn bench_builder<I: Clone>(
&self,
init_input: I,
logic_input: I,
f: impl Fn(&mut SinglePhaseCoreManager<Fr>, &RangeChip<Fr>, I),
) -> BenchStats
pub fn bench_builder<I: Clone>( &self, init_input: I, logic_input: I, f: impl Fn(&mut SinglePhaseCoreManager<Fr>, &RangeChip<Fr>, I), ) -> BenchStats
Runs keygen, real prover, and verifier by providing a closure that uses a builder and RangeChip.
Must provide init_input for use during key generation, which is preferably not equal to logic_input.
These are the inputs to the closure, not necessary public inputs to the circuit.
Currently for testing, no public instances.